@@ -18,6 +18,10 @@
 
 #include <ldns/util.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 enum ldns_enum_status {
 	LDNS_STATUS_OK,	
 	LDNS_STATUS_EMPTY_LABEL,
@@ -94,7 +98,11 @@ enum ldns_enum_status {
 	LDNS_STATUS_DNSSEC_EXISTENCE_DENIED,
 	LDNS_STATUS_DNSSEC_NSEC_RR_NOT_COVERED,
 	LDNS_STATUS_DNSSEC_NSEC_WILDCARD_NOT_COVERED,
-	LDNS_STATUS_DNSSEC_NSEC3_ORIGINAL_NOT_FOUND
+	LDNS_STATUS_DNSSEC_NSEC3_ORIGINAL_NOT_FOUND,
+	LDNS_STATUS_MISSING_RDATA_FIELDS_RRSIG,
+	LDNS_STATUS_MISSING_RDATA_FIELDS_KEY,
+	LDNS_STATUS_CRYPTO_SIG_EXPIRED_WITHIN_MARGIN,
+	LDNS_STATUS_CRYPTO_SIG_NOT_INCEPTED_WITHIN_MARGIN
 };
 typedef enum ldns_enum_status ldns_status;
 
@@ -108,4 +116,8 @@ extern ldns_lookup_table ldns_error_str[];
  */
 const char *ldns_get_errorstr_by_id(ldns_status err);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* LDNS_ERROR_H */
